@@ -4,6 +4,7 @@
 
 #include "showdesktopwidget.h"
 #include "showdesktopplugin.h"
+#include "imageutil.h"
 
 #include <QPainter>
 #include <QIcon>
@@ -27,9 +28,9 @@ void ShowDesktopWidget::paintEvent(QPaintEvent *e)
     QPixmap icon;
 
     if (Dock::Fashion == qApp->property(PROP_DISPLAY_MODE).value<Dock::DisplayMode>()) {
-        icon = QIcon::fromTheme("deepin-toggle-desktop").pixmap(size() * 0.8 * ratio);
+        icon = ImageUtil::loadSvg("deepin-toggle-desktop", QString(), int(size().width() * 0.8), ratio);
     } else {
-        icon = QIcon::fromTheme("deepin-toggle-desktop").pixmap(size() * 0.7 * ratio);
+        icon = ImageUtil::loadSvg("deepin-toggle-desktop", QString(), int(size().width() * 0.7), ratio);
     }
 
     icon.setDevicePixelRatio(ratio);
